function MyHttpRequest(options) {
	this.method = options.method;
	this.url = options.url;
	this.callback = options.callback;
	this.async = (options.async != false);
	this.errorHandler = options.errorHandler;
	this.parse = options.parse;
	this.requestObj = options.requestObj;
	if (!this.errorHandler) {
		this.errorHandler = MyHttpRequest.defaultErrorHandler;
	}
}

MyHttpRequest.prototype.send = function(callback, thisObj, postParams) {
	var successHandler;
	var errorHandler;
	if (typeof callback == "function") {
		successHandler = callback;
		errorHandler = MyHttpRequest.defaultErrorHandler;
	} else if (typeof callback == "object") {
		successHandler = callback.success;
		errorHandler = callback.error;
	}
	thisObj = (thisObj ? thisObj : null);
	var postParameter = "";
	if (postParams) {
		var params = [];
		for (var param in postParams) {
			var paramName = encodeURIComponent(param);
			var paramValue= encodeURIComponent(postParams[param]);
			params.push(paramName + "=" + paramValue);
		}
		postParameter = params.join("&");
	}
	var xhr = this.requestObj;
	if (!xhr) {
		xhr = createXMLHttpRequest();
	}
	try {
		xhr.open(this.method, this.url, this.async);
		if (this.method.toUpperCase() == "POST") {
			xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
		}
		xhr.send(postParameter);
	} catch (e) {
		errorHandler.call(thisObj, 0, "");
		return;
	}
	xhr.onreadystatechange = function() {
		if (xhr.readyState != 4) {
			return;
		}
		var status = 0, statusText = "", responseText = "";
		try {
			status = xhr.status;
			statusText = xhr.statusText;
			responseText = xhr.responseText;
		} catch (e) {
		}
		if (status == 200) {
			successHandler.call(thisObj, responseText, status, statusText);
		} else {
			errorHandler.call(thisObj, status, statusText);
		}
	};
};

function createXMLHttpRequest() {
	try {
		return new XMLHttpRequest();
	} catch (e) {
		try {
			return new ActiveXObject("Msxml2.XMLHTTP");
		} catch (e2) {
			try {
				return new ActiveXObject("Microsoft.XMLHTTP");
			} catch (e3) {
			}
		}
	}
	return null;
}

