var textfield;
var currentVersion;
var networkMonitor;
var debugMode = true;

var ON_LOAD_CALLBACK = {
	success: function(data) {
		if (data) {
			textfield.value = data.content;
			currentVersion = data.version;
		} else {
			textfield.value = "";
			currentVersion = 0;
		}
		showSuccessMessage("データの読み出しに成功しました。");
	},
	error: function(result) {
		showErrorMessage("データの読み出しに失敗しました。");
		debug("errorType:" + result.errorType);
	},
	networkError: function(status, statusText) {
		showNetworkStatus(false);
	}
};
var ON_SAVE_CALLBACK= {
	success: function(data) {
		showSuccessMessage("データの保存に成功しました。");
	},
	conflict: function(remoteData, localData) {
		var confirmMessage =
			"データはサーバ上で変更されています。ローカルのデータで上書きしますか?\n" +
			"サーバ上のデータ:[" + remoteData.content + "]";
		currentVersion = remoteData.version;
		if (!confirm(confirmMessage)) {
			textfield.value = remoteData.content;
		}
		// もう一度保存
		save();
	},
	error: function(result) {
		showErrorMessage("データの保存に失敗しました。");
		debug("errorType:" + result.errorType);
	},
	networkError: function(status, statusText) {
		showNetworkStatus(false);
	}
};

function init() {
	textfield = document.getElementById("textfield");
	initGlobalVars();
	if (!GLOBAL.hasGears) {
		showStatus("<div class='no-gears'>Gearsがインストールされていません。</div>");
	}
	if (!GLOBAL.onlineOnly) {
		initDatabase();
		capture();
		initNetworkMonitor();
	}
	Store.onUpload = ON_SAVE_CALLBACK;
	Store.onDownload = ON_LOAD_CALLBACK;
	Store.init();
}

function initDatabase() {
	// TODO: スキーマのバージョンチェック
	GLOBAL.db.execute(
		"create table if not exists DATA (" +
		" CONTENT text not null," +
		" VERSION integer not null" +
		")");
};

function capture() {
	// 一度でも取り込みが行われていればオフライン利用は可能なので、
	// 改めてキャッシュの更新をする必要はない
	if (GLOBAL.managedStore.currentVersion) {
		return;
	}
	GLOBAL.managedStore.manifestUrl = MANIFEST;
	GLOBAL.managedStore.checkForUpdate();
	var previousVersion = GLOBAL.managedStore.currentVersion;
	
	var timerId = setInterval(function() {
		var currentVersion = GLOBAL.managedStore.currentVersion;
		if (previousVersion != currentVersion ||
			GLOBAL.managedStore.updateStatus == 3 ||
			GLOBAL.managedStore.updateStatus == 0) {
			
			clearInterval(timerId);
			if (GLOBAL.managedStore.updateStatus == 3) {
				showSuccessMessage("UIの更新が失敗しました。" + GLOBAL.managedStore.lastErrorMessage);
			} else {
				showSuccessMessage("UIの更新が完了しました。");
			}
		}
	}, 500);
}
// ネットワーク監視ワーカの初期化
function initNetworkMonitor() {
	var workerPool = google.gears.factory.create(
		GEARS_WORKERPOOL, GEARS_WORKERPOOL_VERSION);
	// ワーカからのメッセージ受信
	workerPool.onmessage = function(msg, sender, msgObj) {
		// "connected"だったら、「オンライン中」と表示する
		var messageText = msgObj.text;
		if (messageText == "connected") {
			showNetworkStatus(true);
		} else {
			showNetworkStatus(false);
		}
	};

	// スクリプトのURLを指定してワーカを作成
	networkMonitor = workerPool.createWorkerFromUrl("NetworkMonitor-all.jsp");
	// "init"メッセージの送信
	workerPool.sendMessage("init", networkMonitor);
	GLOBAL.networkMonitorPool = workerPool;
	GLOBAL.networkMonitor = networkMonitor;
}


function save() {
	var newData = {
		content: textfield.value,
		version: currentVersion
	};
	Store.save(newData);
}
function clearCache() {
	GLOBAL.localServer.removeManagedStore(STORE_NAME);
}

function showNetworkStatus(connected) {
	if (connected) {
		showStatus("<div class='connected'>オンライン中</div>");
	} else {
		showStatus("<div class='disconnected'>オフライン中</div>");
	}
}
function showStatus(message) {
	document.getElementById("appStatus").innerHTML = message;
}

function showMessage(message) {
	var messageArea = document.getElementById("message");
	if (messageArea)
		messageArea.innerHTML = String(message);
}
function showSuccessMessage(message) {
	showMessage("<span class='success'>" + message + "</span>");
}
function showErrorMessage(message) {
	showMessage("<span class='error'>" + message + "</span>");
}
function debug(message) {
	var debugMessageArea = document.getElementById("debug-message");
	if (debugMessageArea && window.debugMode) {
		debugMessageArea.innerHTML += "<br/>" + message;
	}
}
