var textfield;
var debugMode = false;
var currentVersion;

function init() {
	textfield = document.getElementById("textfield");
	RemoteStore.load({
		success: function(data) {
			if (data) {
				textfield.value = data.content;
				currentVersion = data.version;
			} else {
				textfield.value = "";
				currentVersion = 0;
			}
			showSuccessMessage("データのロードに成功しました。");
		},
		error: function(result) {
			showErrorMessage("データの読み込みに失敗しました。");
			debug("errorType:" + result.errorType);
		},
		networkError: function(status, statusText) {
			showErrorMessage("ネットワークに問題が生じています。");
		}
			
	});
}
function save() {
	var newData = {
		content: textfield.value,
		version: currentVersion
	};
	RemoteStore.save(newData, {
		success: function(data) {
			textfield.value = data.content;
			currentVersion = data.version;
			showSuccessMessage("データの保存に成功しました。");
		},
		conflict: function(remoteData, localData) {
			var confirmMessage =
				"データはサーバ上で変更されています。ローカルのデータで上書きしますか?\n" +
				"サーバ上のデータ:[" + remoteData.content + "]";
			currentVersion = remoteData.version;
			if (confirm(confirmMessage)) {
				// もう一度保存
				save();
			} else {
				textfield.value = remoteData.content;
				alert("サーバ上のデータをロードしました。");
			}
		},
		error: function(result) {
			showErrorMessage("データの保存に失敗しました。");
			debug("errorType:" + result.errorType);
		},
		networkError: function(status, statusText) {
			showErrorMessage("ネットワークに問題が生じています。");
		}
			
	});
}
function showMessage(message) {
	var messageArea = document.getElementById("message");
	if (messageArea)
		messageArea.innerHTML = String(message);
}
function showSuccessMessage(message) {
	showMessage("<span class='success'>" + message + "</span>");
}
function showErrorMessage(message) {
	showMessage("<span class='error'>" + message + "</span>");
}
function debug(message) {
	var debugMessageArea = document.getElementById("debug-message");
	if (debugMessageArea && window.debugMode) {
		debugMessageArea.innerHTML += "<br/>" + message;
	}
}
