var textfield;
var currentVersion;
var networkMonitor;
var debugMode = true;

// アプリケーションの名前をセットする
dojox.off.ui.appName = "SimpleDojoOfflineApp";

// このページをオフラインでも表示するために必要なリソースを自動的に収集する
dojox.off.files.slurp();

// Dojo Offlineの初期化
dojox.off.initialize();


var ON_LOAD_CALLBACK = {
	success: function(data) {
		if (data) {
			textfield.value = data.content;
			currentVersion = data.version;
		} else {
			textfield.value = "";
			currentVersion = 0;
		}
		showSuccessMessage("データの読み出しに成功しました。");
	},
	error: function(result) {
		showErrorMessage("データの読み出しに失敗しました。");
		debug("errorType:" + result.errorType);
	},
	networkError: function(status, statusText) {
		showNetworkStatus(false);
	}
};
var ON_SAVE_CALLBACK= {
	success: function(data) {
		showSuccessMessage("データの保存に成功しました。");
	},
	conflict: function(remoteData, localData) {
		// 第三章のサンプルでは、衝突時は以下のように、
		// ダイアログで確認し、再度保存していた。
		// しかし、Dojo Offlineのリプレイ処理は「データマージ→再度保存」
		// という流れを実現しにくい
//		var confirmMessage =
//			"データはサーバ上で変更されています。ローカルのデータで上書きしますか?\n" +
//			"サーバ上のデータ:[" + remoteData.content + "]";
//		currentVersion = remoteData.version;
//		if (!confirm(confirmMessage)) {
//			textfield.value = remoteData.content;
//		}
//		// もう一度保存
//		save();

		// 第三章のサンプルと同じ動きを無理やり実装することも可能だが、
		// ここではむしろリプレイ処理がマージUIと相性が悪いことを示すため
		// あえてそれをしない。
		alert("データがサーバ上で変更されていたため、保存できませんでした。");
	},
	error: function(result) {
		showErrorMessage("データの保存に失敗しました。");
		debug("errorType:" + result.errorType);
	},
	networkError: function(status, statusText) {
		showNetworkStatus(false);
	}
};


function init() {
	textfield = document.getElementById("textfield");
	initGlobalVars();
	if (!GLOBAL.hasGears) {
		showStatus("<div class='no-gears'>Gearsがインストールされていません。</div>");
	}
	if (!GLOBAL.onlineOnly) {
		initDatabase();
	}
	Store.onDownload = ON_LOAD_CALLBACK;
	Store.onUpload = ON_SAVE_CALLBACK;
	Store.init();
}
dojo.connect(dojox.off, "onLoad", null, init);

function initDatabase() {
	// TODO: スキーマのバージョンチェック
	GLOBAL.db.execute(
		"create table if not exists DATA (" +
		" CONTENT text not null," +
		" VERSION integer not null" +
		")");
};

function save() {
	var newData = {
		content: textfield.value,
		version: currentVersion
	};
	Store.save(newData);
}
function clearCache() {
	// Dojo Offline用のキャッシュを削除するよう変更
	var storeName = "dot_store_" 
		+ window.location.href.replace(/[^0-9A-Za-z_]/g, "_");
	GLOBAL.localServer.removeStore(storeName);
	// 古いキャッシュのバージョン番号をストレージから除去	
	dojox.storage.remove('oldVersion', '_dot');
}

function showNetworkStatus(connected) {
	if (connected) {
		showStatus("<div class='connected'>オンライン中</div>");
	} else {
		showStatus("<div class='disconnected'>オフライン中</div>");
	}
}
function showStatus(message) {
	document.getElementById("appStatus").innerHTML = message;
}

function showMessage(message) {
	var messageArea = document.getElementById("message");
	if (messageArea)
		messageArea.innerHTML = String(message);
}
function showSuccessMessage(message) {
	showMessage("<span class='success'>" + message + "</span>");
}
function showErrorMessage(message) {
	showMessage("<span class='error'>" + message + "</span>");
}
function debug(message) {
	var debugMessageArea = document.getElementById("debug-message");
	if (debugMessageArea && window.debugMode) {
		debugMessageArea.innerHTML += "<br/>" + message;
	}
}
